# Define the kmod package name here.
%define kmod_name wl

# If kversion isn't defined on the rpmbuild line, define it here as the currently running kernel.
%{!?kversion: %define kversion $(uname -r)}

Name:    %{kmod_name}-kmod
Version: 6_30_223_271
Release: 3%{?dist}
Group:   System Environment/Kernel
License: Broadcom
Summary: %{kmod_name} kernel module(s)
URL:     http://www.broadcom.com/support/802.11/linux_sta.php

BuildRequires: redhat-rpm-config, kernel-abi-whitelists
ExclusiveArch: i686 x86_64

# Sources.
Source0:  hybrid-v35-nodebug-pcoem-%{version}.tar.gz
Source1:  hybrid-v35_64-nodebug-pcoem-%{version}.tar.gz
Source2:  README_6.30.223.271.txt
Source10: kmodtool-%{kmod_name}-el6.sh

# Ensure that the tarballs ARE NOT packaged.
NoSource: 0
NoSource: 1

# Patches.
Patch0:  wl-kmod-fix-ioctl-handling.patch

# Magic hidden here.
%{expand:%(sh %{SOURCE10} rpmtemplate %{kmod_name} %{kversion} "")}

# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
This package provides the Broadcom hybrid %{kmod_name} kernel module(s).
It is built to depend upon the specific ABI provided by a range of releases
of the same variant of the Linux kernel and not on any one specific build.

%prep
%setup -q -n %{kmod_name}-kmod-%{version} -c -T
%ifarch i686
%setup -q -D -T -a 0
%endif
%ifarch x86_64
%setup -q -D -T -a 1
%endif
%patch0 -p1

# Define kvl & kvr for use below in "patching" logicals
%define kvl %(echo %{kversion} | cut -d"-" -f1)
%define kvr %(echo %{kversion} | cut -d"-" -f2 | cut -d"." -f1)

# Perform "patching" edits to the src/wl/sys/wl_cfg80211_hybrid.c file.
#  Note: Using this method, as opposed to making a patch, allows 
#   the nosrc.rpm to be compiled under various point release kernels.
%if "%{kvl}" == "2.6.32"
#  For all point releases:
%{__sed} -i 's/[ >][>=] KERNEL_VERSION(2, 6, 3.)/>= KERNEL_VERSION(2, 6, 32)/' src/wl/sys/wl_cfg80211_hybrid.c
%if %{kvr} < 279
#  Do not apply to EL 6.0, 6.1 or 6.2 point releases
echo "This specification file is only applicable to kernel-2.6.32-279.el6 and upwards."
false
%endif
%if %{kvr} >= 431
#  Apply to EL 6.5 point release and later
%{__sed} -i  's/[ >][>=] KERNEL_VERSION(3, ., .)/>= KERNEL_VERSION(2, 6, 32)/' src/wl/sys/wl_cfg80211_hybrid.c
%endif
%if %{kvr} >= 573
#  Apply to EL 6.7 point release and later
%{__sed} -i 's/[ >][>=] KERNEL_VERSION(3, 11, .)/>= KERNEL_VERSION(2, 6, 32)/' src/wl/sys/wl_cfg80211_hybrid.c
%{__sed} -i        's/< KERNEL_VERSION(3, 18, .)/< KERNEL_VERSION(2, 6, 30)/' src/wl/sys/wl_cfg80211_hybrid.c
%{__sed} -i 's/[ >][>=] KERNEL_VERSION(3, 15, .)/>= KERNEL_VERSION(2, 6, 32)/' src/wl/sys/wl_cfg80211_hybrid.c
%endif
%if %{kvr} >= 642
#  Apply to EL 6.8 point release and later
%{__sed} -i 's/[ >][>=] KERNEL_VERSION(4, 0, 0)/>= KERNEL_VERSION(2, 6, 32)/' src/wl/sys/wl_cfg80211_hybrid.c
%{__sed} -i        's/< KERNEL_VERSION(4,2,0)/< KERNEL_VERSION(2, 6, 30)/' src/wl/sys/wl_cfg80211_hybrid.c
%endif
%else
echo "This specification file has been written for use with RHEL 6 kernels only."
false
%endif

# Create the module override file.
echo "override %{kmod_name} * weak-updates/%{kmod_name}" > kmod-%{kmod_name}.conf

# Create the file to blacklist certain modules.
%{__cat} <<EOF > blacklist-Broadcom.conf
blacklist b43
blacklist b43legacy
blacklist bcm43xx
blacklist brcmsmac
blacklist ssb
blacklist bcma
EOF

# Create the file to modprobe the modules at system initialisation time.
%{__cat} <<EOF > kmod-%{kmod_name}.modules
#!/bin/bash

for M in lib80211 cfg80211 wl; do
    modprobe $M &>/dev/null
done
EOF

%build
if [ "%{apiwext}" == "1" ]
then
    %{__make} KBUILD_DIR=%{_usrsrc}/kernels/%{kversion} API=WEXT
else
    %{__make} KBUILD_DIR=%{_usrsrc}/kernels/%{kversion}
fi

%install
%{__install} -d %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
%{__install} %{kmod_name}.ko %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
%{__install} -d %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} kmod-%{kmod_name}.conf %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} -d %{buildroot}%{_sysconfdir}/modprobe.d/
%{__install} blacklist-Broadcom.conf %{buildroot}%{_sysconfdir}/modprobe.d/
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig/modules/
%{__install} kmod-%{kmod_name}.modules %{buildroot}%{_sysconfdir}/sysconfig/modules/
%{__install} -d %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
%{__install} %{SOURCE2} %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/README.txt
%{__install} lib/LICENSE.txt %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
# Set the module(s) to be executable, so that they will be stripped when packaged.
find %{buildroot} -type f -name \*.ko -exec %{__chmod} u+x \{\} \;
# Remove the unrequired files.
%{__rm} -f %{buildroot}/lib/modules/%{kversion}/modules.*

%clean
%{__rm} -rf %{buildroot}

%changelog
* Tue May 10 2016 S.Tindall <s10dal@elrepo.org> - 6_30_223_271-3
- Modified src/wl/sys/wl_cfg80211_hybrid.c
-  to allow build against RHEL 6.8

* Mon Oct 5 2015 S.Tindall <s10dal@elrepo.org> - 6_30_223_271-2
- Edit comments (No functional changes)

* Sun Oct 4 2015 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_271-1
- Updated to use the 6_30_223_271 tarballs.

* Tue Jul 22 2014 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_248-2
- Added a BuildRequires: kernel-abi-whitelists

* Mon Jul 21 2014 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_248-1
- Updated to use the 6_30_223_248 tarballs.

* Thu Dec 05 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_141-2
- Revised the edits of the src/wl/sys/wl_cfg80211_hybrid.c file
- to allow the package to build against RHEL 6u5 kernels.

* Fri Sep 27 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 6_30_223_141-1
- Updated to use the 6_30_223_141 tarballs.

* Wed Mar 20 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-9
- Corrected the 'here' document. [http://elrepo.org/bugs/view.php?id=369]

* Sun Mar 10 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-8
- Modified the conditional test to be string based.

* Sat Mar 09 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-7
- Applied wl-kmod-fix-ioctl-handling.patch [http://elrepo.org/bugs/view.php?id=303]

* Wed Mar 06 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-6
- Add support for WEXT API (make API=WEXT) to support older hardware [http://elrepo.org/bugs/view.php?id=365]

* Tue Mar 05 2013 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-5
- Blacklisted the bcma module. [milosb] [http://elrepo.org/bugs/view.php?id=357]

* Fri Jul 13 2012 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-4
- Patched wl_cfg80211.c for EL6. [P J Welsh][http://elrepo.org/bugs/view.php?id=286]

* Sun Mar 18 2012 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-3
- Re-wrote this spec file. [Yves Delannoy][http://elrepo.org/bugs/view.php?id=238]

* Wed Feb 29 2012 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-2
- Added API=CFG80211 to the make modules line. [janne][http://elrepo.org/bugs/view.php?id=238]

* Thu Oct 27 2011 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_112-1
- Updated to use the 5_100_82_112 tarballs.
- Blacklisted the bcm43xx module.

* Wed Jun 01 2011 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_38-2
- Allow building for the currently running kernel, by default.
- Blacklist the interfering modules.

* Tue May 31 2011 The Doctor <DrWho@Gallifrey.Kasterborus> - 5_100_82_38-1
- Initial el6 build of the kmod package.
